/****************************************************************************

Package:            de.mvcsys.epocutil
Class:              EpocException

Task:               Special Exception for EPOC applications

Author:             Marcus von Cube

Updates:

Datum     Name  Vers.  Bemerkung
-----------------------------------------------------------------------------
20.04.05  MvC   1.0    created

****************************************************************************/

package de.mvcsys.epocutil;

/**
 *  <p>Special Exception for EPOC applications.</p>
 *  <p>It wraps the EPOC error codes.</p>
 */
public class EpocException extends java.io.IOException
{
    public static final int KErrNone = 0;
    public static final int KErrNotFound = -1;
    public static final int KErrGeneral = -2;
    public static final int KErrCancel = -3;
    public static final int KErrNoMemory = -4;
    public static final int KErrNotSupported = -5;
    public static final int KErrArgument = -6;
    public static final int KErrTotalLossOfPrecision = -7;
    public static final int KErrBadHandle = -8;
    public static final int KErrOverflow = -9;
    public static final int KErrUnderflow = -10;
    public static final int KErrAlreadyExists = -11;
    public static final int KErrPathNotFound = -12;
    public static final int KErrDied = -13;
    public static final int KErrInUse = -14;
    public static final int KErrServerTerminated = -15;
    public static final int KErrServerBusy = -16;
    public static final int KErrCompletion = -17;
    public static final int KErrNotReady = -18;
    public static final int KErrUnknown = -19;
    public static final int KErrCorrupt = -20;
    public static final int KErrAccessDenied = -21;
    public static final int KErrLocked = -22;
    public static final int KErrWrite = -23;
    public static final int KErrDisMounted = -24;
    public static final int KErrEof = -25;
    public static final int KErrDiskFull = -26;
    public static final int KErrBadDriver = -27;
    public static final int KErrBadName = -28;
    public static final int KErrCommsLineFail = -29;
    public static final int KErrCommsFrame = -30;
    public static final int KErrCommsOverrun = -31;
    public static final int KErrCommsParity = -32;
    public static final int KErrTimedOut = -33;
    public static final int KErrCouldNotConnect = -34;
    public static final int KErrCouldNotDisconnect = -35;
    public static final int KErrDisconnected = -36;
    public static final int KErrBadLibraryEntryPoint = -37;
    public static final int KErrBadDescriptor = -38;
    public static final int KErrAbort = -39;
    public static final int KErrTooBig = -40;
    public static final int KErrDivideByZero = -41;
    public static final int KErrBadPower = -42;
    public static final int KErrDirFull = -43;

    public static final String[] ErrorNames =
    {
        "None",
        "NotFound",
        "General",
        "Cancel",
        "NoMemory",
        "NotSupported",
        "Argument",
        "TotalLossOfPrecision",
        "BadHandle",
        "Overflow",
        "Underflow",
        "AlreadyExists",
        "PathNotFound",
        "Died",
        "InUse",
        "ServerTerminated",
        "ServerBusy",
        "Completion",
        "NotReady",
        "Unknown",
        "Corrupt",
        "AccessDenied",
        "Locked",
        "Write",
        "DisMounted",
        "Eof",
        "DiskFull",
        "BadDriver",
        "BadName",
        "CommsLineFail",
        "CommsFrame",
        "CommsOverrun",
        "CommsParity",
        "TimedOut",
        "CouldNotConnect",
        "CouldNotDisconnect",
        "Disconnected",
        "BadLibraryEntryPoint",
        "BadDescriptor",
        "Abort",
        "TooBig",
        "DivideByZero",
        "BadPower",
        "DirFull"
    };

    /**
     *  EPOC reason code
     */
    public final int reason;

    /**
     *  Construct using reason code
     */
    public EpocException( int reason )
    {
        super( reason <= 0 && -reason < ErrorNames.length
               ? ErrorNames[ -reason ] + " / " + reason
               : "reason = " + reason );
        this.reason = reason;
    }

}
