/****************************************************************************

Package:            mcutil
Class:              Liste

Aufgabe:            Einfaches Dictionary fuer IniFile

Programmierer:      Marcus von Cube, EasyData (MvC)

Aenderungen:

Datum     Name  Vers.  Bemerkung
-----------------------------------------------------------------------------
27.02.97  MvC   0.1    erstellt
01.04.97  MvC   1.0    in Package aufgenommen
16.05.03  MvC   2.0    reorganisiert, neues Package, Base64

****************************************************************************/

package de.mvcsys.util;

import java.util.Vector;
import java.util.Dictionary;
import java.util.Enumeration;

/*
 *  Ein Dictionary fuer die Sections und ihre Elemente
 */
class Liste extends Dictionary
{
    /**
     *  Hilfsklasse zur Erzeugung der Enumerationen von Liste
     */
    protected class EnumListe implements Enumeration
    {
        private Enumeration enum;
        private int was;

        public EnumListe( Enumeration enum, int was )
        {
            this.enum = enum;
            this.was = was % 3;
        }

        public boolean hasMoreElements()
        {
            return enum.hasMoreElements();
        }

        public Object nextElement()
        {
            Object triple[] = (Object[]) enum.nextElement();
            return triple[ was ];
        }
    }

    /**
     *  Konstante: Wert ist encoded
     */
    public static final Object ENCODED = new Boolean( true );

    /**
     *  Konstante: Wert ist nicht encoded
     */
    public static final Object NOT_ENCODED = new Boolean( false );

    /**
     *  Datenspeicher
     */
    protected Vector inhalt;

    /*
     *  Konstruktor
     */
    public Liste()
    {
        inhalt = new Vector();
    }

    /**
     *  Suche einen Eintrag
     *  return Array mit Name und Daten und Boolean (encoded)
     */
    protected synchronized Object[] find( Object name )
    {
        int size = inhalt.size();
        
        for ( int i = 0; i < size; ++i ) {
            Object triple[] = (Object[]) inhalt.elementAt( i );
            if ( triple[ 0 ].equals( name ) ) {
                return triple;
            }
        }
        return null;
    }

    /**
     *  Suche einen Eintrag
     *  @return Index des Eintrags im Vector
     */
    protected synchronized int findIndex( Object name )
    {
        int size = inhalt.size();
        
        for ( int i = 0; i < size; ++i ) {
            Object triple[] = (Object[]) inhalt.elementAt( i );
            if ( triple[ 0 ].equals( name ) ) {
                return i;
            }
        }
        return -1;
    }


    /**
     *  Encode (nur f&uuml;r Strings)
     */
    protected static String encode( String val )
    {
        return Base64.encode( val );
    }


    /**
     *  Encode (nur f&uuml;r Strings)
     */
    protected static String decode( String val )
    {
        return Base64.decode( val );
    }


    /**
     *  Einf&uuml;gen
     */
    public synchronized Object put( Object name, Object wert )
    {
        return put( name, wert, false );
    }

    /**
     *  Einf&uuml;gen
     */
    public synchronized Object put( Object name, Object wert,
                                    boolean encoded )
    {
        Object result = null;
        Object triple[] = find( name );
        if ( triple != null ) {
            result = triple[ 1 ];
        }
        else {
            triple = new Object[ 3 ];
            triple[ 0 ] = name;
            inhalt.addElement( triple );
        }
        if ( encoded ) {
            triple[ 1 ] = encode( (String) wert );
            triple[ 2 ] = ENCODED;
        }
        else {
            triple[ 1 ] = wert;
            triple[ 2 ] = NOT_ENCODED;
        }
        return result;
    }

    /**
     *  Lesen
     */
    public synchronized Object get( Object name )
    {
        Object triple[] = find( name );

        if ( triple != null ) {
            return triple[ 2 ] == ENCODED
                   ? decode( (String) triple[ 1 ] )
                   : triple[ 1 ];
        }
        return null;
    }

    /**
     *  Loeschen
     */
    public synchronized Object remove( Object name )
    {
        int i = findIndex( name );

        if ( i >= -1 ) {
            Object triple[] = (Object[]) inhalt.elementAt( i );
            inhalt.removeElementAt( i );
            return triple[ 2 ] == ENCODED
                   ? decode( (String) triple[ 1 ] )
                   : triple[ 1 ];
        }
        return null;
    }

    /**
     *  Gr&ouml;&szlig;e
     */
    public int size()
    {
        return inhalt.size();
    }

    /**
     *  Leer?
     */
    public boolean isEmpty()
    {
        return size() == 0;
    }

    /**
     *  Enumeration der Schl&uuml;ssel
     */
    public Enumeration keys()
    {
        return new EnumListe( inhalt.elements(), 0 );
    }

    /**
     *  Enumeration der Elemente
     */
    public Enumeration elements()
    {
        return new EnumListe( inhalt.elements(), 1 );
    }
}

